@@ -12,6 +12,7 @@ import (
 	"path/filepath"
 	"regexp"
 	"runtime"
+	"strconv"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -166,6 +167,19 @@ func FlagCompletionFunc(allCompletions []string) func(*cobra.Command, []string,
 	}
 }
 
+// ParseBool is like strconv.ParseBool but also accepts on, ON, y, Y, yes, YES,
+// n, N, no, NO, off, and OFF.
+func ParseBool(str string) (bool, error) {
+	switch strings.ToLower(strings.TrimSpace(str)) {
+	case "n", "no", "off":
+		return false, nil
+	case "on", "y", "yes":
+		return true, nil
+	default:
+		return strconv.ParseBool(str)
+	}
+}
+
 // SHA256Sum returns the SHA256 sum of data.
 func SHA256Sum(data []byte) []byte {
 	sha256SumArr := sha256.Sum256(data)
@@ -194,6 +208,28 @@ func SuspiciousSourceDirEntry(base string, fileInfo fs.FileInfo, encryptedSuffix
 	}
 }
 
+// UniqueAbbreviations returns a map of unique abbreviations of values to
+// values. Values always map to themselves.
+func UniqueAbbreviations(values []string) map[string]string {
+	abbreviations := make(map[string][]string)
+	for _, value := range values {
+		for i := 1; i <= len(value); i++ {
+			abbreviation := value[:i]
+			abbreviations[abbreviation] = append(abbreviations[abbreviation], value)
+		}
+	}
+	uniqueAbbreviations := make(map[string]string)
+	for abbreviation, values := range abbreviations {
+		if len(values) == 1 {
+			uniqueAbbreviations[abbreviation] = values[0]
+		}
+	}
+	for _, value := range values {
+		uniqueAbbreviations[value] = value
+	}
+	return uniqueAbbreviations
+}
+
 // etcHostnameFQDNHostname returns the FQDN hostname from parsing /etc/hostname.
 func etcHostnameFQDNHostname(fileSystem vfs.FS) (string, error) {
 	contents, err := fileSystem.ReadFile("/etc/hostname")
