@@ -2,6 +2,7 @@ package chezmoi
 
 import (
 	"os"
+	"strings"
 	"testing"
 
 	"github.com/rs/zerolog"
@@ -109,6 +110,73 @@ func TestEtcHostsFQDNHostname(t *testing.T) {
 	}
 }
 
+func TestUniqueAbbreviations(t *testing.T) {
+	for _, tc := range []struct {
+		values   []string
+		expected map[string]string
+	}{
+		{
+			values:   nil,
+			expected: map[string]string{},
+		},
+		{
+			values: []string{
+				"yes",
+				"no",
+				"all",
+				"quit",
+			},
+			expected: map[string]string{
+				"y":    "yes",
+				"ye":   "yes",
+				"yes":  "yes",
+				"n":    "no",
+				"no":   "no",
+				"a":    "all",
+				"al":   "all",
+				"all":  "all",
+				"q":    "quit",
+				"qu":   "quit",
+				"qui":  "quit",
+				"quit": "quit",
+			},
+		},
+		{
+			values: []string{
+				"ale",
+				"all",
+				"abort",
+			},
+			expected: map[string]string{
+				"ale":   "ale",
+				"all":   "all",
+				"ab":    "abort",
+				"abo":   "abort",
+				"abor":  "abort",
+				"abort": "abort",
+			},
+		},
+		{
+			values: []string{
+				"no",
+				"now",
+				"nope",
+			},
+			expected: map[string]string{
+				"no":   "no",
+				"now":  "now",
+				"nop":  "nope",
+				"nope": "nope",
+			},
+		},
+	} {
+		t.Run(strings.Join(tc.values, "_"), func(t *testing.T) {
+			actual := UniqueAbbreviations(tc.values)
+			assert.Equal(t, tc.expected, actual)
+		})
+	}
+}
+
 func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
 	keys := maps.Keys(m)
 	slices.Sort(keys)
