@@ -619,60 +619,6 @@ func (s *SourceState) Apply(
 			return err
 		}
 
-		// Mitigate a bug in chezmoi before version 2.0.10 in a user-friendly
-		// way.
-		//
-		// chezmoi before version 2.0.10 incorrectly stored the last written
-		// entry state permissions, due to buggy umask handling. This caused
-		// chezmoi apply to raise a false positive that a file or directory had
-		// been modified since chezmoi last wrote it, since the permissions did
-		// not match. Further compounding the problem, the diff presented to the
-		// user was empty as the target state matched the actual state.
-		//
-		// The mitigation consists of several parts. First, detect that the bug
-		// as precisely as possible by detecting where the the target state,
-		// actual state, and last written entry state permissions match when the
-		// umask is considered.
-		//
-		// If this is the case, then patch the last written entry state as if
-		// the permissions were correctly stored.
-		//
-		// Finally, try to update the last written entry state in the persistent
-		// state so we don't hit this path the next time the user runs chezmoi
-		// apply. We ignore any errors because the persistent state might be in
-		// read-only or dry-run mode.
-		//
-		// FIXME remove this mitigation in a later version of chezmoi
-		switch {
-		case lastWrittenEntryState == nil:
-		case lastWrittenEntryState.Type == EntryStateTypeFile:
-			if targetStateFile, ok := targetStateEntry.(*TargetStateFile); ok {
-				if actualStateFile, ok := actualStateEntry.(*ActualStateFile); ok {
-					if actualStateFile.perm.Perm() == targetStateFile.perm.Perm() {
-						if targetStateFile.perm.Perm() != lastWrittenEntryState.Mode.Perm() {
-							if targetStateFile.perm.Perm() == lastWrittenEntryState.Mode.Perm()&^s.umask {
-								lastWrittenEntryState.Mode = targetStateFile.perm
-								_ = persistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), lastWrittenEntryState)
-							}
-						}
-					}
-				}
-			}
-		case lastWrittenEntryState.Type == EntryStateTypeDir:
-			if targetStateDir, ok := targetStateEntry.(*TargetStateDir); ok {
-				if actualStateDir, ok := actualStateEntry.(*ActualStateDir); ok {
-					if actualStateDir.perm.Perm() == targetStateDir.perm.Perm() {
-						if targetStateDir.perm.Perm() != lastWrittenEntryState.Mode.Perm() {
-							if targetStateDir.perm.Perm() == lastWrittenEntryState.Mode.Perm()&^s.umask {
-								lastWrittenEntryState.Mode = fs.ModeDir | targetStateDir.perm
-								_ = persistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), lastWrittenEntryState)
-							}
-						}
-					}
-				}
-			}
-		}
-
 		// If the target entry state matches the actual entry state, but not the
 		// last written entry state then silently update the last written entry
 		// state. This handles the case where the user makes identical edits to
@@ -823,6 +769,7 @@ TARGET:
 
 // ReadOptions are options to SourceState.Read.
 type ReadOptions struct {
+	ReadHTTPResponse func(*http.Response) ([]byte, error)
 	RefreshExternals bool
 	TimeNow          func() time.Time
 }
@@ -1363,7 +1310,12 @@ func (s *SourceState) getExternalDataRaw(
 	if err != nil {
 		return nil, err
 	}
-	data, err := io.ReadAll(resp.Body)
+	var data []byte
+	if options == nil || options.ReadHTTPResponse == nil {
+		data, err = io.ReadAll(resp.Body)
+	} else {
+		data, err = options.ReadHTTPResponse(resp)
+	}
 	resp.Body.Close()
 	if err != nil {
 		return nil, err
