@@ -81,6 +81,7 @@ type ConfigFile struct {
 	Mode               chezmoi.Mode                    `mapstructure:"mode"`
 	Pager              string                          `mapstructure:"pager"`
 	PINEntry           pinEntryConfig                  `mapstructure:"pinentry"`
+	Progress           bool                            `mapstructure:"progress"`
 	Safe               bool                            `mapstructure:"safe"`
 	ScriptTempDir      chezmoi.AbsPath                 `mapstructure:"scriptTempDir"`
 	SourceDirAbsPath   chezmoi.AbsPath                 `mapstructure:"sourceDir"`
@@ -101,6 +102,7 @@ type ConfigFile struct {
 	Lastpass          lastpassConfig          `mapstructure:"lastpass"`
 	Onepassword       onepasswordConfig       `mapstructure:"onepassword"`
 	Pass              passConfig              `mapstructure:"pass"`
+	Passhole          passholeConfig          `mapstructure:"passhole"`
 	Secret            secretConfig            `mapstructure:"secret"`
 	Vault             vaultConfig             `mapstructure:"vault"`
 
@@ -192,6 +194,8 @@ type Config struct {
 	tempDirs map[string]chezmoi.AbsPath
 
 	ioregData ioregData
+
+	restoreWindowsConsole func() error
 }
 
 // A configOption sets and option on a Config.
@@ -296,6 +300,10 @@ func newConfig(options ...configOption) (*Config, error) {
 		Pass: passConfig{
 			Command: "pass",
 		},
+		Passhole: passholeConfig{
+			Command: "ph",
+			Prompt:  true,
+		},
 		Vault: vaultConfig{
 			Command: "vault",
 		},
@@ -459,6 +467,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"pass":                     c.passTemplateFunc,
 		"passFields":               c.passFieldsTemplateFunc,
 		"passRaw":                  c.passRawTemplateFunc,
+		"passhole":                 c.passholeTemplateFunc,
 		"quoteList":                c.quoteListTemplateFunc,
 		"replaceAllRegex":          c.replaceAllRegexTemplateFunc,
 		"secret":                   c.secretTemplateFunc,
@@ -1355,6 +1364,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
 	persistentFlags.Var(&c.Mode, "mode", "Mode")
 	persistentFlags.Var(&c.persistentStateAbsPath, "persistent-state", "Set persistent state file")
+	persistentFlags.BoolVar(&c.Progress, "progress", c.Progress, "Display progress bars")
 	persistentFlags.BoolVar(&c.Safe, "safe", c.Safe, "Safely replace files and symlinks")
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
 	persistentFlags.Var(&c.UseBuiltinAge, "use-builtin-age", "Use builtin age")
@@ -1366,6 +1376,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		"color":           "color",
 		"destDir":         "destination",
 		"persistentState": "persistent-state",
+		"progress":        "progress",
 		"mode":            "mode",
 		"safe":            "safe",
 		"sourceDir":       "source",
@@ -1524,6 +1535,7 @@ func (c *Config) newSourceState(
 
 	if err := s.Read(ctx, &chezmoi.ReadOptions{
 		RefreshExternals: c.refreshExternals,
+		ReadHTTPResponse: c.readHTTPResponse,
 	}); err != nil {
 		return nil, err
 	}
@@ -1572,6 +1584,12 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
+	if c.restoreWindowsConsole != nil {
+		if err := c.restoreWindowsConsole(); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -1622,6 +1640,14 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
+	if runtime.GOOS == "windows" {
+		var err error
+		c.restoreWindowsConsole, err = enableVirtualTerminalProcessing(c.stdout)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Read the config file.
 	if err := c.readConfig(); err != nil {
 		if !boolAnnotation(cmd, doesNotRequireValidConfig) {
@@ -1630,19 +1656,11 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.errorf("warning: %s: %v\n", c.configFileAbsPath, err)
 	}
 
-	// Determine whether color should be used.
-	color := c.Color.Value(c.colorAutoFunc)
-	if color {
-		if err := enableVirtualTerminalProcessing(c.stdout); err != nil {
-			return err
-		}
-	}
-
 	// Configure the logger.
 	log.Logger = log.Output(zerolog.NewConsoleWriter(
 		func(w *zerolog.ConsoleWriter) {
 			w.Out = c.stderr
-			w.NoColor = !color
+			w.NoColor = !c.Color.Value(c.colorAutoFunc)
 			w.TimeFormat = time.RFC3339
 		},
 	))
@@ -1846,21 +1864,6 @@ func (c *Config) persistentStateFile() (chezmoi.AbsPath, error) {
 	return defaultConfigFileAbsPath.Dir().Join(persistentStateFileRelPath), nil
 }
 
-// promptChoice prompts the user for one of choices until a valid choice is made.
-func (c *Config) promptChoice(prompt string, choices []string) (string, error) {
-	promptWithChoices := fmt.Sprintf("%s [%s]? ", prompt, strings.Join(choices, ","))
-	abbreviations := uniqueAbbreviations(choices)
-	for {
-		line, err := c.readLine(promptWithChoices)
-		if err != nil {
-			return "", err
-		}
-		if value, ok := abbreviations[strings.TrimSpace(line)]; ok {
-			return value, nil
-		}
-	}
-}
-
 // readConfig reads the config file, if it exists.
 func (c *Config) readConfig() error {
 	viper.SetConfigFile(c.configFileAbsPath.String())
@@ -1880,22 +1883,6 @@ func (c *Config) readConfig() error {
 	return nil
 }
 
-// readLine reads a line from stdin, trimming leading and trailing whitespace.
-func (c *Config) readLine(prompt string) (string, error) {
-	_, err := c.stdout.Write([]byte(prompt))
-	if err != nil {
-		return "", err
-	}
-	if c.bufioReader == nil {
-		c.bufioReader = bufio.NewReader(c.stdin)
-	}
-	line, err := c.bufioReader.ReadString('\n')
-	if err != nil {
-		return "", err
-	}
-	return strings.TrimSpace(line), nil
-}
-
 // run runs name with args in dir.
 func (c *Config) run(dir chezmoi.AbsPath, name string, args []string) error {
 	cmd := exec.Command(name, args...)
@@ -2192,7 +2179,8 @@ func (c *Config) writeOutput(data []byte) error {
 		_, err := c.stdout.Write(data)
 		return err
 	}
-	return c.baseSystem.WriteFile(c.outputAbsPath, data, 0o666)
+	//nolint:gosec
+	return os.WriteFile(c.outputAbsPath.String(), data, 0o666)
 }
 
 // writeOutputString writes data to the configured output.
