@@ -209,17 +209,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			name:    "dest-dir",
 			dirname: c.DestDirAbsPath,
 		},
-		&binaryCheck{
-			name:       "shell-command",
-			binaryname: shellCommand,
-			ifNotSet:   checkResultError,
-			ifNotExist: checkResultError,
-		},
-		&argsCheck{
-			name:    "shell-args",
-			command: shellCommand,
-			args:    shellArgs,
-		},
+		umaskCheck{},
 		&binaryCheck{
 			name:       "cd-command",
 			binaryname: cdCommand,
@@ -231,6 +221,12 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			command: cdCommand,
 			args:    cdArgs,
 		},
+		&binaryCheck{
+			name:       "diff-command",
+			binaryname: c.Diff.Command,
+			ifNotSet:   checkResultInfo,
+			ifNotExist: checkResultWarning,
+		},
 		&binaryCheck{
 			name:       "edit-command",
 			binaryname: editCommand,
@@ -242,13 +238,6 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			command: editCommand,
 			args:    editArgs,
 		},
-		&binaryCheck{
-			name:       "diff-command",
-			binaryname: c.Diff.Command,
-			ifNotSet:   checkResultInfo,
-			ifNotExist: checkResultWarning,
-		},
-		umaskCheck{},
 		&binaryCheck{
 			name:        "git-command",
 			binaryname:  c.Git.Command,
@@ -263,6 +252,17 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			ifNotSet:   checkResultWarning,
 			ifNotExist: checkResultWarning,
 		},
+		&binaryCheck{
+			name:       "shell-command",
+			binaryname: shellCommand,
+			ifNotSet:   checkResultError,
+			ifNotExist: checkResultError,
+		},
+		&argsCheck{
+			name:    "shell-args",
+			command: shellCommand,
+			args:    shellArgs,
+		},
 		&binaryCheck{
 			name:        "age-command",
 			binaryname:  c.Age.Command,
@@ -320,6 +320,12 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionArgs: []string{"--version"},
 			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
 		},
+		&fileCheck{
+			name:       "keepassxc-db",
+			filename:   c.Keepassxc.Database,
+			ifNotSet:   checkResultInfo,
+			ifNotExist: checkResultInfo,
+		},
 		&binaryCheck{
 			name:        "keeper-command",
 			binaryname:  c.Keeper.Command,
@@ -328,12 +334,6 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionArgs: []string{"version"},
 			versionRx:   regexp.MustCompile(`^Commander\s+Version:\s+(\d+\.\d+\.\d+)`),
 		},
-		&fileCheck{
-			name:       "keepassxc-db",
-			filename:   c.Keepassxc.Database,
-			ifNotSet:   checkResultInfo,
-			ifNotExist: checkResultInfo,
-		},
 		&binaryCheck{
 			name:        "lastpass-command",
 			binaryname:  c.Lastpass.Command,
@@ -351,6 +351,15 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionArgs: []string{"version"},
 			versionRx:   regexp.MustCompile(`(?m)=\s*v(\d+\.\d+\.\d+)`),
 		},
+		&binaryCheck{
+			name:        "passhole-command",
+			binaryname:  c.Passhole.Command,
+			ifNotSet:    checkResultWarning,
+			ifNotExist:  checkResultInfo,
+			versionArgs: []string{"--version"},
+			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
+			minVersion:  &passholeMinVersion,
+		},
 		&binaryCheck{
 			name:        "vault-command",
 			binaryname:  c.Vault.Command,
