@@ -1,7 +1,6 @@
 package cmd
 
 import (
-	"strconv"
 	"strings"
 	"unicode"
 )
@@ -20,6 +19,11 @@ var (
 		"all",
 		"quit",
 	}
+	choicesYesNoQuit = []string{
+		"yes",
+		"no",
+		"quit",
+	}
 )
 
 // englishList returns ss formatted as a list, including an Oxford comma.
@@ -70,19 +74,6 @@ func isWellKnownAbbreviation(word string) bool {
 	return ok
 }
 
-// parseBool is like strconv.ParseBool but also accepts on, ON, y, Y, yes, YES,
-// n, N, no, NO, off, and OFF.
-func parseBool(str string) (bool, error) {
-	switch strings.ToLower(strings.TrimSpace(str)) {
-	case "n", "no", "off":
-		return false, nil
-	case "on", "y", "yes":
-		return true, nil
-	default:
-		return strconv.ParseBool(str)
-	}
-}
-
 // pluralize returns the English plural form of singular.
 func pluralize(singular string) string {
 	if strings.HasSuffix(singular, "y") {
@@ -114,28 +105,6 @@ func upperSnakeCaseToCamelCase(s string) string {
 	return strings.Join(words, "")
 }
 
-// uniqueAbbreviations returns a map of unique abbreviations of values to
-// values. Values always map to themselves.
-func uniqueAbbreviations(values []string) map[string]string {
-	abbreviations := make(map[string][]string)
-	for _, value := range values {
-		for i := 1; i <= len(value); i++ {
-			abbreviation := value[:i]
-			abbreviations[abbreviation] = append(abbreviations[abbreviation], value)
-		}
-	}
-	uniqueAbbreviations := make(map[string]string)
-	for abbreviation, values := range abbreviations {
-		if len(values) == 1 {
-			uniqueAbbreviations[abbreviation] = values[0]
-		}
-	}
-	for _, value := range values {
-		uniqueAbbreviations[value] = value
-	}
-	return uniqueAbbreviations
-}
-
 // upperSnakeCaseToCamelCaseKeys returns m with all keys converted from
 // UPPER_SNAKE_CASE to camelCase.
 func upperSnakeCaseToCamelCaseMap(m map[string]any) map[string]any {
